arc_deref_spec

Function arc_deref_spec 

pub fn arc_deref_spec<T>(a: Arc<T>)
👎Deprecated: If you can, do not use this module as it adds assumptions about the core of Rust’s deref semantics.
ensures
#[trigger] *(a.deref_spec()) == *a,