box_deref_spec

Function box_deref_spec 

pub fn box_deref_spec<T>(b: Box<T>)
👎Deprecated: If you can, do not use this module as it adds assumptions about the core of Rust’s deref semantics.
ensures
#[trigger] *(b.deref_spec()) == *b,