group_deref_spec

Function group_deref_spec 

pub fn group_deref_spec()
👎Deprecated: If you can, do not use this module as it adds assumptions about the core of Rust’s deref semantics.
broadcast group