rc_deref_spec

Function rc_deref_spec 

pub fn rc_deref_spec<T>(r: Rc<T>)
👎Deprecated: If you can, do not use this module as it adds assumptions about the core of Rust’s deref semantics.
ensures
#[trigger] *(r.deref_spec()) == *r,