ref_deref_spec

Function ref_deref_spec 

pub fn ref_deref_spec<T>(r: &T)
👎Deprecated: If you can, do not use this module as it adds assumptions about the core of Rust’s deref semantics.
ensures
#[trigger] *(r.deref_spec()) == *r,